@@ -14,7 +14,7 @@ from .json_data import JSONData
 class AVROData(JSONData, BaseData):
     """AVROData class to save and load spreadsheet data."""
 
-    data_type: Optional[str] = "avro"
+    data_type: str = "avro"
 
     def __init__(
         self,
@@ -56,7 +56,7 @@ class AVROData(JSONData, BaseData):
     def file_encoding(self, value: Any) -> None:
         """Do nothing.
 
-        Required by mypy because the inherited self.file_encoding is read-write).
+        Required by mypy because the inherited self.file_encoding is read-write.
         """
         pass
 
@@ -91,13 +91,13 @@ class AVROData(JSONData, BaseData):
             options = dict()
 
         # get current position of stream
-        if data_utils.is_stream_buffer(file_path) and not isinstance(file_path, str):
+        if data_utils.is_stream_buffer(file_path):
             starting_location = file_path.tell()
 
         is_valid_avro = fastavro.is_avro(file_path)
 
         # return to original position in stream
-        if data_utils.is_stream_buffer(file_path) and not isinstance(file_path, str):
+        if data_utils.is_stream_buffer(file_path):
             file_path.seek(starting_location, 0)
 
         return is_valid_avro
