@@ -1,6 +1,9 @@
 """Contains factory class reading various kinds of data."""
 from __future__ import absolute_import, division
 
+from io import BytesIO
+from typing import Any, Dict, List, Optional, Union, cast
+
 from .. import dp_logging
 from .avro_data import AVROData
 from .csv_data import CSVData
@@ -16,7 +19,7 @@ logger = dp_logging.get_child_logger(__name__)
 class Data(object):
     """Factory class for reading various kinds of data."""
 
-    data_classes = [
+    data_classes: List[Dict] = [
         dict(data_class=JSONData, kwargs=dict()),
         dict(data_class=GraphData, kwargs=dict()),
         dict(data_class=CSVData, kwargs=dict()),
@@ -25,7 +28,13 @@ class Data(object):
         dict(data_class=TextData, kwargs=dict()),
     ]
 
-    def __new__(cls, input_file_path=None, data=None, data_type=None, options=None):
+    def __new__(
+        cls,
+        input_file_path: Optional[Union[str, BytesIO]] = None,
+        data: Optional[Any] = None,
+        data_type: Optional[str] = None,
+        options: Optional[Dict] = None,
+    ):
         """
         Create Factory Data object.
 
@@ -54,7 +63,7 @@ class Data(object):
             )
 
         if not options:
-            options = dict()
+            options = cast(Dict, dict())
 
         if is_valid_url(input_file_path):
             input_file_path = url_to_bytes(input_file_path, options)
