@@ -5,12 +5,14 @@ import json
 import os
 import sys
 import warnings
-from typing import Dict, List, Optional, Union, cast
+from typing import Dict, List, Optional, Type, Union, cast
 
 import numpy as np
 import pandas as pd
 import pkg_resources
 
+from dataprofiler._typing import DataArray
+
 from .. import data_readers
 from . import data_processing
 from .base_model import BaseModel
@@ -133,7 +135,7 @@ class BaseDataLabeler(object):
         return self._preprocessor
 
     @property
-    def model(self) -> Optional[BaseModel]:
+    def model(self) -> BaseModel:
         """
         Retrieve the data labeler model.
 
@@ -152,8 +154,8 @@ class BaseDataLabeler(object):
 
     @staticmethod
     def _check_and_return_valid_data_format(
-        data: Union[pd.DataFrame, pd.Series, np.ndarray], fit_or_predict: str = "fit"
-    ) -> Union[pd.DataFrame, pd.Series, np.ndarray]:
+        data: DataArray, fit_or_predict: str = "fit"
+    ) -> DataArray:
         """
         Check incoming data to match the specified fit or predict format.
 
@@ -273,7 +275,7 @@ class BaseDataLabeler(object):
 
     def predict(
         self,
-        data: Union[pd.DataFrame, pd.Series, np.ndarray],
+        data: DataArray,
         batch_size: int = 32,
         predict_options: Dict[str, bool] = None,
         error_on_mismatch: bool = False,
@@ -287,7 +289,7 @@ class BaseDataLabeler(object):
         :param batch_size: batch size of prediction
         :type batch_size: int
         :param predict_options: optional parameters to allow for predict as a
-            dict, i.e.  dict(show_confidences=True)
+            dict, i.e. dict(show_confidences=True)
         :type predict_options: Dict[str, bool]
         :param error_on_mismatch: if true, errors instead of warns on parameter
             mismatches in pipeline
@@ -509,7 +511,9 @@ class BaseDataLabeler(object):
             params["postprocessor"]["class"] = load_options.get("postprocessor_class")
         return params
 
-    def _load_model(self, model_class: Union[BaseModel, str], dirpath: str) -> None:
+    def _load_model(
+        self, model_class: Optional[Union[Type[BaseModel], str]], dirpath: str
+    ) -> None:
         """
         Load the data labeler model.
 
@@ -517,24 +521,25 @@ class BaseDataLabeler(object):
         retrieving a registered data labeler model.
 
         :param model_class: class of model being loaded
-        :type model_class: Union[BaseModel, str]
+        :type model_class: Union[Type[BaseModel], str]
         :param dirpath: directory where the saved DataLabeler model exists.
         :type dirpath: str
         :return: None
         """
         if isinstance(model_class, str):
-            model_class: BaseModel = BaseModel.get_class(model_class)  # type: ignore
+            model_class = BaseModel.get_class(model_class)
+
         if not model_class:
             raise ValueError(
                 "`model_class`, {}, was not set in load_options "
                 "and could not be found as a registered model "
                 "class in BaseModel.".format(str(model_class))
             )
-        self.set_model(cast(BaseModel, model_class).load_from_disk(dirpath))
+        self.set_model(model_class.load_from_disk(dirpath))
 
     def _load_preprocessor(
         self,
-        processor_class: Union[data_processing.BaseDataProcessor, str],
+        processor_class: Optional[Union[Type[data_processing.BaseDataProcessor], str]],
         dirpath: str,
     ) -> None:
         """
@@ -557,21 +562,22 @@ class BaseDataLabeler(object):
                 "class in BaseDataProcessor.".format(str(processor_class))
             )
         self.set_preprocessor(
-            cast(data_processing.BaseDataProcessor, processor_class).load_from_disk(
-                dirpath
+            cast(
+                data_processing.BaseDataPreprocessor,
+                processor_class.load_from_disk(dirpath),
             )
         )
 
     def _load_postprocessor(
         self,
-        processor_class: Union[data_processing.BaseDataProcessor, str],
+        processor_class: Optional[Union[Type[data_processing.BaseDataProcessor], str]],
         dirpath: str,
     ) -> None:
         """
         Load the postprocessor for the data labeler.
 
         :param processor_class: class of model being loaded
-        :type processor_class: Union[data_processing.BaseDataProcessor, str]
+        :type processor_class: Union[Type[data_processing.BaseDataPostprocessor], str]
         :param dirpath: directory where the saved DataLabeler model exists.
         :type dirpath: str
         :return: None
@@ -589,8 +595,9 @@ class BaseDataLabeler(object):
                 )
             )
         self.set_postprocessor(
-            cast(data_processing.BaseDataProcessor, processor_class).load_from_disk(
-                dirpath
+            cast(
+                data_processing.BaseDataPostprocessor,
+                processor_class.load_from_disk(dirpath),
             )
         )
 
@@ -655,7 +662,7 @@ class BaseDataLabeler(object):
         postprocessor: data_processing.BaseDataPostprocessor,
     ) -> BaseDataLabeler:
         """
-        Load the data labeler from a its set  of components.
+        Load the data labeler from a its set of components.
 
         :param preprocessor: processor to set as the preprocessor
         :type preprocessor: data_processing.BaseDataPreprocessor
@@ -753,8 +760,8 @@ class TrainableDataLabeler(BaseDataLabeler):
 
     def fit(
         self,
-        x: Union[pd.DataFrame, pd.Series, np.ndarray],
-        y: Union[pd.DataFrame, pd.Series, np.ndarray],
+        x: DataArray,
+        y: DataArray,
         validation_split: float = 0.2,
         labels: Union[List, Dict] = None,
         reset_weights: bool = False,
@@ -775,7 +782,7 @@ class TrainableDataLabeler(BaseDataLabeler):
         :param labels: Encoding or number of labels if refit is needed to new
             labels
         :type labels: Union[list, dict]
-        :param reset_weights:  Flag to determine whether or not to reset the
+        :param reset_weights: Flag to determine whether or not to reset the
             weights
         :type reset_weights: bool
         :param batch_size: Size of each batch sent to data labeler model
@@ -892,7 +899,7 @@ class TrainableDataLabeler(BaseDataLabeler):
         postprocessor: data_processing.BaseDataPostprocessor,
     ) -> TrainableDataLabeler:
         """
-        Load the data labeler from a its set  of components.
+        Load the data labeler from a its set of components.
 
         :param preprocessor: processor to set as the preprocessor
         :type preprocessor: data_processing.BaseDataPreprocessor
