@@ -1,7 +1,10 @@
 """Contains class for profiling datetime column."""
+from __future__ import annotations
+
 import datetime
 import re
 import warnings
+from typing import Dict, List, Optional, Union
 
 import numpy as np
 import pandas as pd
@@ -50,7 +53,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         r"(\d{1,2})(" + "|".join(_day_suffixes) + ")"
     )
 
-    def __init__(self, name, options=None):
+    def __init__(self, name: Optional[str], options: DateTimeOptions = None) -> None:
         """
         Initialize it and the column base properties.
 
@@ -64,16 +67,16 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
                 "DateTimeColumn parameter 'options' must be of " "type DateTimeOptions."
             )
         BaseColumnPrimitiveTypeProfiler.__init__(self, name)
-        self.date_formats = []
+        self.date_formats: List[str] = []
         self.min = None
         self.max = None
         self._dt_obj_min = None  # datetime obj of min
         self._dt_obj_max = None  # datetime obj of max
 
-        self.__calculations = {}
+        self.__calculations: Dict = {}
         self._filter_properties_w_options(self.__calculations, options)
 
-    def __add__(self, other):
+    def __add__(self, other: DateTimeColumn) -> DateTimeColumn:
         """
         Merge the properties of two DateTimeColumn profiles.
 
@@ -117,7 +120,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         )
         return merged_profile
 
-    def report(self, remove_disabled_flag=False):
+    def report(self, remove_disabled_flag: bool = False) -> Dict:
         """
         Return report.
 
@@ -130,7 +133,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         return self.profile
 
     @property
-    def profile(self):
+    def profile(self) -> Dict:
         """Return the profile of the column."""
         profile = dict(
             min=self.min,
@@ -142,7 +145,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         return profile
 
     @property
-    def data_type_ratio(self):
+    def data_type_ratio(self) -> Optional[float]:
         """
         Calculate the ratio of samples which match this data type.
 
@@ -153,7 +156,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
             return float(self.match_count) / self.sample_size
         return None
 
-    def diff(self, other_profile, options=None):
+    def diff(self, other_profile: DateTimeColumn, options: Dict = None) -> Dict:
         """
         Generate differences between max, min, and formats of two DateTime cols.
 
@@ -177,7 +180,9 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         return differences
 
     @staticmethod
-    def _validate_datetime(date, date_format):
+    def _validate_datetime(
+        date: str, date_format: str
+    ) -> Union[datetime.datetime, float]:
         """
         Check to see if a string contains a certain date format.
 
@@ -188,14 +193,16 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         :return: either the str converted into a date format, or Nan
         """
         try:
-            converted_date = datetime.datetime.strptime(date, date_format)
+            converted_date: Union[
+                datetime.datetime, float
+            ] = datetime.datetime.strptime(date, date_format)
         except (ValueError, TypeError):
             converted_date = np.nan
 
         return converted_date
 
     @staticmethod
-    def _replace_day_suffix(date, pattern):
+    def _replace_day_suffix(date: str, pattern: re.Pattern) -> Union[str, float]:
         """
         Check the date for a suffix after the day. Remove suffix if present.
 
@@ -206,13 +213,13 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         :return: either the date string passed in, or Nan
         """
         try:
-            date = pattern.sub(r"\1", date)
+            new_date: Union[str, float] = pattern.sub(r"\1", date)
         except (TypeError):
-            date = np.nan
-        return date
+            new_date = np.nan
+        return new_date
 
     @classmethod
-    def _get_datetime_profile(cls, df_series):
+    def _get_datetime_profile(cls, df_series: pd.Series) -> Dict:
         """
         Determine for each val in a col its format and if it's a datetime.
 
@@ -223,8 +230,8 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         :return: parameters for datetime columns
         :rtype: dict
         """
-        profile = dict()
-        activated_date_formats = list()
+        profile: Dict = dict()
+        activated_date_formats: List = list()
         len_df = len(df_series)
 
         is_row_datetime = pd.Series(np.full((len(df_series)), False))
@@ -238,7 +245,9 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
                 break
             valid_dates = df_series.apply(
                 lambda x: cls._validate_datetime(
-                    cls._replace_day_suffix(x, cls._compiled_day_suffix_regex),
+                    cls._replace_day_suffix(  # type: ignore
+                        x, cls._compiled_day_suffix_regex
+                    ),
                     date_format,
                 )
             )
@@ -300,19 +309,19 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         profile["min"] = min_value
         profile["max"] = max_value
         profile["min_obj"] = (
-            min_value_obj.to_datetime()
+            min_value_obj.to_datetime()  # type: ignore
             if hasattr(min_value_obj, "to_datetime")
             else min_value_obj
         )
         profile["max_obj"] = (
-            max_value_obj.to_datetime()
+            max_value_obj.to_datetime()  # type: ignore
             if hasattr(max_value_obj, "to_datetime")
             else max_value_obj
         )
         profile["match_count"] = is_row_datetime.sum()
         return profile
 
-    def _is_subset_datetime_column(self, df_series):
+    def _is_subset_datetime_column(self, df_series: pd.Series) -> bool:
         """
         Check whether a subset of the data could be considered datetime.
 
@@ -333,7 +342,12 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         return True
 
     @BaseColumnProfiler._timeit(name="datetime")
-    def _update_datetime(self, df_series, prev_dependent_properties, subset_properties):
+    def _update_datetime(
+        self,
+        df_series: pd.DataFrame,
+        prev_dependent_properties: Dict,
+        subset_properties: Dict,
+    ) -> None:
         """
         Calculate the datetime properties for the profile.
 
@@ -376,7 +390,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
 
         subset_properties.update(profile)
 
-    def _update_helper(self, df_series, profile):
+    def _update_helper(self, df_series: pd.Series, profile: Dict) -> None:
         """
         Update the column profile properties.
 
@@ -388,7 +402,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         """
         self._update_column_base_properties(profile)
 
-    def update(self, df_series):
+    def update(self, df_series: pd.Series) -> DateTimeColumn:
         """
         Update the column profile.
 
