@@ -1,10 +1,11 @@
 from dataprofiler.profilers.profiler_options import BaseInspectorOptions
-from dataprofiler.tests.profilers.profiler_options.test_boolean_option import \
-    TestBooleanOption
+from dataprofiler.tests.profilers.profiler_options.test_boolean_option import (
+    TestBooleanOption,
+)
 
 
 class TestBaseInspectorOptions(TestBooleanOption):
-    
+
     option_class = BaseInspectorOptions
 
     @classmethod
@@ -13,19 +14,19 @@ class TestBaseInspectorOptions(TestBooleanOption):
         options = cls.option_class()
         options.set(params)
         return options
-            
+
     def test_init(self):
         super().test_init()
-    
+
     def test_set_helper(self):
         super().test_set_helper()
 
     def test_set(self):
         super().test_set()
-    
+
     def test_validate_helper(self):
         super().test_validate_helper()
-    
+
     def test_validate(self):
         super().test_validate()
 
@@ -38,13 +39,11 @@ class TestBaseInspectorOptions(TestBooleanOption):
         self.assertTrue(options.is_prop_enabled("is_enabled"))
         options.set({"is_enabled": False})
         self.assertFalse(options.is_prop_enabled("is_enabled"))
-    
-        # Check is prop enabled for invalid property    
-        expected_error = 'Property "Hello World" does not exist in {}.' \
-                         .format(optpth)
+
+        # Check is prop enabled for invalid property
+        expected_error = 'Property "Hello World" does not exist in {}.'.format(optpth)
         with self.assertRaisesRegex(AttributeError, expected_error):
             options.is_prop_enabled("Hello World")
 
     def test_eq(self):
         super().test_eq()
-
